@@ -29,6 +29,7 @@ import errno
 import optparse
 import os
 import shutil
+import stat
 import subprocess
 import sys
 import tempfile
@@ -139,6 +140,9 @@ def _get_option_parser():
     parser.add_option("-l", "--library",
                       action="append", dest="libraries", default=[],
                       help="libraries of this unit")
+    parser.add_option("", "--extra-library",
+                      action="append", dest="extra_libraries", default=[],
+                      help="Extra libraries to link the binary against")
     parser.add_option("-L", "--library-path",
                       action="append", dest="library_paths", default=[],
                       help="directories to search for libraries")
@@ -450,6 +454,13 @@ def write_output(data, options):
         output = sys.stdout
     elif options.reparse_validate_gir:
         main_f, main_f_name = tempfile.mkstemp(suffix='.gir')
+
+        if (os.path.isfile(options.output)):
+            shutil.copystat(options.output, main_f_name)
+        else:
+            os.chmod(main_f_name,
+                     stat.S_IWUSR | stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH)
+
         with os.fdopen(main_f, 'wb') as main_f:
             main_f.write(data)
 
@@ -465,7 +476,6 @@ def write_output(data, options):
         except OSError as e:
             if e.errno == errno.EPERM:
                 os.unlink(main_f_name)
-                return 0
             raise
         return 0
     else:
@@ -552,7 +562,7 @@ def scanner_main(args):
     if options.warn_fatal and warning_count > 0:
         message.fatal("warnings configured as fatal")
         return 1
-    elif warning_count > 0 and options.warn_all is False:
+    elif warning_count > 0 and options.warn_all is False and options.quiet is False:
         print("g-ir-scanner: %s: warning: %d warnings suppressed "
               "(use --warn-all to see them)" %
               (transformer.namespace.name, warning_count, ))
